@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # This file is part of python-ly, https://pypi.python.org/pypi/python-ly
 #
 # Copyright (c) 2008 - 2015 by Wilbert Berendsen
@@ -30,10 +31,10 @@ except:
     from urllib import urlopen
 
 
-VERSION = "2.17"
+VERSION = "2.18"
 GUILE_URL = "https://www.gnu.org/software/guile/docs/docs-1.8/guile-ref/Procedure-Index.html#Procedure-Index"
-LY_FUNCTION_URL = "http://lilypond.org/doc/v2.17/Documentation/internals/scheme-functions"
-SCM_PATH = os.path.join(os.environ['HOME'], 'lilypond/usr/share/lilypond/current/scm')
+LY_FUNCTION_URL = "http://lilypond.org/doc/v2.18/Documentation/internals/scheme-functions"
+SCM_PATH = os.path.join(os.environ['HOME'], 'lilypond_bin/2.18.2-1/lilypond/usr/share/lilypond/current/scm')
 
 GUILE_IGNONED_TYPE = (
     'Apply Traps',
@@ -96,7 +97,7 @@ schemeDataPath = os.path.join(os.path.split(__file__)[0], '_scheme_data.py')
 
 def main():
     with open(schemeDataPath, "w") as f:
-        f.write("#! python\n#generated by makeschemedata.py\n\nversion=\"{}\"\n\n".format(VERSION))
+        f.write("#generated by makeschemedata.py\n\nversion=\"{}\"\n\n".format(VERSION))
         
         guileWords = []
         for m in guilePat.finditer(guilePage.decode('utf-8')):
