@@ -90,22 +90,32 @@ class ParseSource():
         self.slurnr = 0
         self.phrslurnr = 0
 
-    def parse_text(self, ly_text):
-        """Parse the LilyPond source as text."""
+    def parse_text(self, ly_text, filename=None):
+        """Parse the LilyPond source specified as text.
+        
+        If you specify a filename, it can be used to resolve \\include commands
+        correctly.
+        
+        """
         doc = ly.document.Document(ly_text)
+        doc.filename = filename
         self.parse_document(doc)
 
-    def parse_document(self, ly_doc):
-        """Parse the LilyPond source as a ly.document document.
-
-        The document is converted to absolute mode to facilitate the export.
-        Use parse_text instead if you want the document to be unaffected.
-
+    def parse_document(self, ly_doc, relative_first_pitch_absolute=False):
+        """Parse the LilyPond source specified as a ly.document document.
+        
+        If relative_first_pitch_absolute is set to True, the first pitch in a
+        \relative expression without startpitch is considered to be absolute
+        (LilyPond 2.18+ behaviour).
+        
         """
+        # The document is copied and the copy is converted to absolute mode to
+        # facilitate the export. The original document is unchanged.
+        doc = ly_doc.copy()
         import ly.pitch.rel2abs
-        cursor = ly.document.Cursor(ly_doc)
-        ly.pitch.rel2abs.rel2abs(cursor)
-        mustree = ly.music.document(ly_doc)
+        cursor = ly.document.Cursor(doc)
+        ly.pitch.rel2abs.rel2abs(cursor, first_pitch_absolute=relative_first_pitch_absolute)
+        mustree = ly.music.document(doc)
         self.parse_tree(mustree)
 
     def parse_tree(self, mustree):
@@ -164,6 +174,9 @@ class ParseSource():
             val = a.value().get_string()
             if not val:
                 self.schm_assignm = a.name()
+        elif isinstance(a.value(), ly.music.items.UserCommand):
+            # Don't know what to do with this:
+            return
         if self.look_behind(a, ly.music.items.With):
             if self.with_contxt in group_contexts:
                 self.mediator.set_by_property(a.name(), val, True)
@@ -178,7 +191,7 @@ class ParseSource():
                 self.mediator.new_snippet('sim-snip')
                 self.voice_sep = True
             else:
-                self.mediator.new_section('simultan', True)
+                self.mediator.new_section('simultan')
                 self.sims_and_seqs.append('sim')
         elif musicList.token == '{':
             self.sims_and_seqs.append('seq')
@@ -269,7 +282,11 @@ class ParseSource():
                 self.mediator.set_relative(note)
                 self.rel_pitch_isset = True
             elif isinstance(note.parent(), ly.music.items.Chord):
-                self.mediator.new_chord(note, note.parent().duration, self.relative)
+                if self.mediator.current_chord:
+                    self.mediator.new_chord(note, chord_base=False)
+                else:
+                    self.mediator.new_chord(note, note.parent().duration, self.relative)
+                    self.check_tuplet()
                 # chord as grace note
                 if self.grace_seq:
                     self.mediator.new_chord_grace()
@@ -291,6 +308,14 @@ class ParseSource():
 
     def check_note(self, note):
         """Generic check for all notes, both pitched and unpitched."""
+        self.check_tuplet()
+        if self.grace_seq:
+            self.mediator.new_grace()
+        if self.trem_rep and not self.look_ahead(note, ly.music.items.Duration):
+            self.mediator.set_tremolo(trem_type='start', repeats=self.trem_rep)
+
+    def check_tuplet(self):
+        """Generic tuplet check."""
         if self.tuplet:
             tlevels = len(self.tuplet)
             nested = True if tlevels > 1 else False
@@ -303,10 +328,6 @@ class ParseSource():
                                                 td['nr'])
                 td['ttype'] = ""
             self.mediator.check_divs()
-        if self.grace_seq:
-            self.mediator.new_grace()
-        if self.trem_rep and not self.look_ahead(note, ly.music.items.Duration):
-            self.mediator.set_tremolo(trem_type='start', repeats=self.trem_rep)
 
     def Duration(self, duration):
         """A written duration"""
@@ -722,4 +743,3 @@ class ParseSource():
         """Call any function in the mediator object."""
         func_call = getattr(self.mediator, func_name)
         func_call(*args)
-
