@@ -137,26 +137,28 @@ class IterateXmlObjs():
 
     def before_note(self, obj):
         """Xml-nodes before note."""
-        for d in obj.dynamic:
-            if d.before:
-                if d.is_mark:
-                    self.musxml.add_dynamic_mark(d.sign)
-                else:
-                    self.musxml.add_dynamic_wedge(d.sign)
+        self._add_dynamics([d for d in obj.dynamic if d.before])
         if obj.oct_shift and not obj.oct_shift.octdir == 'stop':
             self.musxml.add_octave_shift(obj.oct_shift.plac, obj.oct_shift.octdir, obj.oct_shift.size)
 
     def after_note(self, obj):
         """Xml-nodes after note."""
-        for d in obj.dynamic:
-            if not d.before:
-                if d.is_mark:
-                    self.musxml.add_dynamic_mark(d.sign)
-                else:
-                    self.musxml.add_dynamic_wedge(d.sign)
+        self._add_dynamics([d for d in obj.dynamic if not d.before])
         if obj.oct_shift and obj.oct_shift.octdir == 'stop':
             self.musxml.add_octave_shift(obj.oct_shift.plac, obj.oct_shift.octdir, obj.oct_shift.size)
 
+    def _add_dynamics(self, dyns):
+        """Add XML nodes for list of Dynamics objects."""
+        for d in dyns:
+            if isinstance(d, DynamicsMark):
+                self.musxml.add_dynamic_mark(d.sign)
+            elif isinstance(d, DynamicsWedge):
+                self.musxml.add_dynamic_wedge(d.sign)
+            elif isinstance(d, DynamicsText):
+                self.musxml.add_dynamic_text(d.sign)
+            elif isinstance(d, DynamicsDashes):
+                self.musxml.add_dynamic_dashes(d.sign)
+
     def gener_xml_mus(self, obj):
         """Nodes generic for both notes and rests."""
         if obj.tuplet:
@@ -226,6 +228,7 @@ class Score():
         self.creators = {}
         self.info = {}
         self.rights = None
+        self.glob_section = ScoreSection('global', True)
 
     def is_empty(self):
         """Check if score is empty."""
@@ -234,6 +237,11 @@ class Score():
         else:
             return True
 
+    def merge_globally(self, section, override=False):
+        """Merge section to all parts."""
+        for p in self.partlist:
+            p.merge_voice(section, override)
+
     def debug_score(self, attr=[]):
         """
         Loop through score and print all elements for debugging purposes.
@@ -280,21 +288,26 @@ class ScorePartGroup():
     def set_bracket(self, bracket):
         self.bracket = bracket
 
+    def merge_voice(self, voice, override=False):
+        """Merge in a ScoreSection into all parts."""
+        for part in self.partlist:
+            part.merge_voice(voice, override)
+
 
 class ScoreSection():
     """ object to keep track of music section """
-    def __init__(self, name, sim=False):
+    def __init__(self, name, glob=False):
         self.name = name
         self.barlist = []
-        self.simultan = sim
+        self.glob = glob
 
     def __repr__(self):
         return '<{0} {1}>'.format(self.__class__.__name__, self.name)
 
-    def merge_voice(self, voice):
+    def merge_voice(self, voice, override=False):
         """Merge in other ScoreSection."""
         for org_v, add_v in zip(self.barlist, voice.barlist):
-            org_v.inject_voice(add_v)
+            org_v.inject_voice(add_v, override)
         bl_len = len(self.barlist)
         if len(voice.barlist) > bl_len:
             self.barlist += voice.barlist[bl_len:]
@@ -395,6 +408,24 @@ class ScorePart(ScoreSection):
         else:
             self.to_part.barlist.extend(self.barlist)
 
+    def extract_global_to_section(self, name):
+        """Extract only elements that is relevant for the score globally into a given section."""
+        section = ScoreSection(name, True)
+        for bar in self.barlist:
+            section_bar = Bar()
+            for obj in bar.obj_list:
+                if isinstance(obj, BarAttr):
+                    glob_barattr = BarAttr()
+                    glob_barattr.key = obj.key
+                    glob_barattr.time = obj.time
+                    glob_barattr.mode = obj.mode
+                    glob_barattr.barline = obj.barline
+                    glob_barattr.repeat = obj.repeat
+                    glob_barattr.tempo = obj.tempo
+                    section_bar.obj_list.append(glob_barattr)
+            section.barlist.append(section_bar)
+        return section
+
 
 class Bar():
     """ Representing the bar/measure.
@@ -443,13 +474,13 @@ class Bar():
                     return False
         return True
 
-    def inject_voice(self, new_voice):
+    def inject_voice(self, new_voice, override=False):
         """ Adding new voice to bar.
-        Omitting double or conflicting bar attributes.
+        Omitting double or conflicting bar attributes as long as override is false.
         Omitting also bars with only skips."""
         if new_voice.obj_list[0].has_attr():
             if self.obj_list[0].has_attr():
-                self.obj_list[0].merge_attr(new_voice.obj_list[0])
+                self.obj_list[0].merge_attr(new_voice.obj_list[0], override)
             else:
                 self.obj_list.insert(0, new_voice.obj_list[0])
             backup_list = new_voice.obj_list[1:]
@@ -495,14 +526,17 @@ class BarMus():
     def add_other_notation(self, other):
         self.other_notation = other
 
-    def set_dynamics(self, mark=None, wedge=None, before=True):
-        if mark:
-            sign = mark
-            is_mark = True
-        if wedge:
-            sign = wedge
-            is_mark = False
-        self.dynamic.append(Dynamics(sign, before, is_mark))
+    def set_dynamics_mark(self, sign, before=True):
+        self.dynamic.append(DynamicsMark(sign, before))
+
+    def set_dynamics_wedge(self, sign, before=True):
+        self.dynamic.append(DynamicsWedge(sign, before))
+
+    def set_dynamics_text(self, sign, before=True):
+        self.dynamic.append(DynamicsText(sign, before))
+
+    def set_dynamics_dashes(self, sign, before=True):
+        self.dynamic.append(DynamicsDashes(sign, before))
 
     def set_oct_shift(self, plac, octdir, size):
         self.oct_shift = OctaveShift(plac, octdir, size)
@@ -526,12 +560,31 @@ class OctaveShift():
 
 class Dynamics():
     """Stores information about dynamics. """
-    def __init__(self, sign, before=True, is_mark=False, ):
+    def __init__(self, sign, before=True):
         self.before = before
-        self.is_mark = is_mark
         self.sign = sign
 
 
+class DynamicsMark(Dynamics):
+    """A dynamics mark."""
+    pass
+
+
+class DynamicsWedge(Dynamics):
+    """A dynamics wedge/hairpin."""
+    pass
+
+
+class DynamicsText(Dynamics):
+    """A dynamics text."""
+    pass
+
+
+class DynamicsDashes(Dynamics):
+    """Dynamics dashes."""
+    pass
+
+
 class Tuplet():
     """Stores information about tuplet."""
     def __init__(self, fraction, ttype, nr, acttype, normtype):
@@ -675,7 +728,7 @@ class BarAttr():
         self.tempo = None
 
     def __repr__(self):
-        return '<{0}>'.format(self.__class__.__name__)
+        return '<{0} {1}>'.format(self.__class__.__name__, self.time)
 
     def set_key(self, muskey, mode):
         self.key = muskey
@@ -709,18 +762,20 @@ class BarAttr():
             check = True
         return check
 
-    def merge_attr(self, barattr):
-        """Merge in attributes (from another bar)."""
-        if self.key is None and barattr.key is not None:
+    def merge_attr(self, barattr, override=False):
+        """Merge in attributes (from another bar).
+        Existing attributes will only be replaced when override is set to true.
+        """
+        if barattr.key is not None and (override or self.key is None):
             self.key = barattr.key
             self.mode = barattr.mode
-        if self.time == 0 and barattr.time != 0:
+        if barattr.time != 0 and (override or self.time == 0):
             self.time = barattr.time
-        if self.clef == 0 and barattr.clef != 0:
+        if barattr.clef != 0 and (override or self.clef == 0):
             self.clef = barattr.clef
         if barattr.multiclef:
             self.multiclef += barattr.multiclef
-        if self.tempo is None and barattr.tempo is not None:
+        if barattr.tempo is not None and (override or self.tempo is None):
             self.tempo = barattr.tempo
 
 
@@ -786,4 +841,3 @@ def convert_barl(bl):
         return 'light-heavy'
     elif bl == "'":
         return 'tick'
-
